#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.

from django.contrib.auth.models import User
from django.db import models
from jenkinsserver.models.jenkins_server import JenkinsServer

class Loop(models.Model):
    class Meta:
        app_label = 'frontend'

    name = models.CharField(max_length=200, unique=True)
    server = models.ForeignKey(JenkinsServer)
    branch = models.CharField(max_length=200, null=True)
    precommand = models.CharField(max_length=200, null=True)
    command = models.CharField(max_length=200, null=True)

    def save(self, *args, **kwargs):
        server = JenkinsServer.objects.get(id=1)
        self.server = server
        server.add_integration_loop(self)
        if (True):
            super(Loop, self).save(*args, **kwargs)
        else:
            raise

    def schedule_build(self):
        '''Add a LoopBuild record for this Loop.

        Also try to send a build job signal to the server, but if it fails,
        ignore it.
        '''
        from frontend.models.loop_build import LoopBuild
        build = LoopBuild()
        build.loop = self
        build.status = 'scheduled'
        build.duration = 0.00
        build.save()
        try:
            self.server.schedule_job_build(self.name)
        except:
            pass
        return build
