#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.

from django.test import TestCase
from django.contrib.auth.models import User, Group
from django.test.client import Client


class ClientResponseTests(TestCase):

    def setUp(self):
        self.client = Client()
        self.user = 'someuser'
        self.passwd = 'somepasswd'
        self.email = 'someuser@example.com'
        self.group = 'somegroup'
        self.user = User.objects.create_user(self.user,
                    self.email, self.passwd)
        self.group = Group.objects.create(name=self.group)

    def tearDown(self):
        user = User.objects.filter(username=self.user)
        group = Group.objects.filter(name=self.group)
        if user:
            user.delete()
        if group:
            group.delete()

    # Test case should fail if the login_required decorator source code
    # in index_view.py is removed.
    def test_response_index_when_user_not_auth_by_login_required(self):
        response = self.client.get('/index/')
        self.assertNotEqual(200, response.status_code)

    def test_response_home_when_user_not_auth_by_login_required(self):
        response = self.client.get('/home/')
        self.assertNotIn(str(self.user), response.content)

    def test_response_with_invalid_user(self):
        passwd = 'invalid_passwd'
        login_value = self.client.login(username=self.user, password=passwd)
        self.assertEqual(login_value, False)

    def test_response_when_user_authed(self):
        self.client.login(username=self.user, password=self.passwd)
        response = self.client.get('/')
        self.assertIn(str(self.user), response.content)
        response = self.client.get('/home/')
        self.assertIn(str(self.user), response.content)
