#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.
from django.core.management.base import CommandError
from django.contrib.auth.models import User
from django.test import TestCase
from mock import Mock, patch

import frontend.management.commands.setsuperuser as setsuperuser
from frontend.views.home_page_view import HomePageView
from frontend.views.index_view import IndexView


class HomePageViewTest(TestCase):

    def test_get_context_data(self):
        home_page_view = HomePageView()
        home_page_view.request = "some request data"
        context = HomePageView.get_context_data(home_page_view)
        self.assertEqual(context['request'], "some request data")


class IndexViewTest(TestCase):

    def test_get_context_data(self):
        index_view = IndexView()
        index_view.request = "some request data"
        context = IndexView.get_context_data(index_view)
        self.assertEqual(context['request'], "some request data")


class SetsuperuserCommandTest(TestCase):

    def setUp(self):
        self.command = setsuperuser.Command()

    def test_find_and_update_user_non_existing(self):
        self.assertRaises(CommandError,
                          self.command.find_and_update_user,
                          ("non_existing_user"))

    def test_find_and_update_user(self):
        user = User(username="existing_user")
        user.save()
        self.command.find_and_update_user("existing_user")
        user = User.objects.get(username="existing_user")
        self.assertEquals(user.is_staff, True)
        self.assertEquals(user.is_superuser, True)
