#!/usr/bin/env python
# Copyright (C) 2012 Linaro
#
# This file is part of linaro-ci-dashboard.
#
# linaro-ci-dashboard is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# linaro-ci-dashboard is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with linaro-ci-dashboard.  If not, see <http://www.gnu.org/licenses/>.

from django.contrib.auth.decorators import login_required
from django.core.urlresolvers import reverse
from django.http import HttpResponseRedirect
from django.views.generic.edit import CreateView
from django.utils.decorators import method_decorator
from frontend.forms.loop_form import LoopForm
from frontend.models.loop import Loop

class LoopCreateView(CreateView):

    template_name = "loop_create.html"
    form_class = LoopForm
    model = Loop

    def form_valid(self, form):
        """This method is called when valid form data has been POSTed.

        It should return an HttpResponse."""

        return super(LoopCreateView, self).form_valid(form)

    @method_decorator(login_required)
    def dispatch(self, *args, **kwargs):
        return super(LoopCreateView, self).dispatch(*args, **kwargs)

    def get_context_data(self, **kwargs):
        '''Get the context data passed to template.'''
        context = super(LoopCreateView, self).get_context_data(**kwargs)
        context['request'] = self.request
        return context

    def get_success_url(self):
        '''Return the URL when the form is valid.'''
        return reverse('LoopDetail', args=[self.object.name])
